@@ -25,26 +25,20 @@
 #define __JSTK_H_INCLUDED__
 
 
+#define MAXBUTTONS 32
+#define MAXAXES 32
+#define MAXKEYSPERBUTTON 4
 
 
 /******************************************************************************
  * debugging macro
  *****************************************************************************/
 #ifdef DBG
-#undef DBG
+    #undef DBG
 #endif
-#ifdef DEBUG
-#undef DEBUG
-#endif
-
-#define DEBUG 1
-
-/**
- * DEBUG Makros
- **/
 
 #if DEBUG
-    extern int      debug_level;
+    extern int debug_level;
     #define DBG(lvl, f) {if ((lvl) <= debug_level) f;}
 #else
     #define DBG(lvl, f)
@@ -52,7 +46,7 @@
 
 
 typedef enum _JOYSTICKTYPE{
-    TYPE_NONE=0,        /* Axis value is not relevant */
+    TYPE_NONE=0,      /* Axis value is not relevant */
     TYPE_BYVALUE,     /* Speed of cursor is relative to amplitude */
     TYPE_ACCELERATED, /* Speed is accelerated */
     TYPE_ABSOLUTE     /* The amplitude defines the cursor position */
@@ -72,33 +66,32 @@ typedef enum _JOYSTICKMAPPING{
     MAPPING_DISABLE_KEYS    /* Disable only key events */
 } JOYSTICKMAPPING;
 
+typedef unsigned int KEYSCANCODES [MAXKEYSPERBUTTON];
 
 typedef struct _AXIS {
     JOYSTICKTYPE    type;
     JOYSTICKMAPPING mapping;
-    int             value;
+    int             value, oldvalue;
     int             valuator;
     int             deadzone;
-    float           currentspeed;
-    float           previousposition;
+    float           currentspeed; /* TYPE_ACCELERATED */
+    float           previousposition; /* TYPE_ABSOLUTE */
     float           amplify;
+    float           subpixel; /* Pending subpixel movement */
+    KEYSCANCODES    keys_low, keys_high;  /* MAPPING_KEY */
 } AXIS;
 
-#define MAXKEYSPERBUTTON 4
-
 typedef struct _BUTTON {
-   JOYSTICKMAPPING mapping;
-   char pressed;
-   int buttonnumber;    /* MAPPING_BUTTON */
-   float amplify;       /* MAPPING_X/Y/ZX/ZY, 
-                           MAPPING_SPEED_MULTIPLY */
-   float currentspeed;  /* MAPPING_X/Y/ZX/ZY */
-   unsigned int keys[MAXKEYSPERBUTTON]; /* MAPPING_KEY */
+    JOYSTICKMAPPING mapping;
+    char            pressed;
+    int             buttonnumber;    /* MAPPING_BUTTON */
+    float           amplify;       /* MAPPING_X/Y/ZX/ZY, 
+                                      MAPPING_SPEED_MULTIPLY */
+    float           currentspeed;  /* MAPPING_X/Y/ZX/ZY */
+    float           subpixel; /* Pending subpixel movement */
+    KEYSCANCODES    keys;   /* MAPPING_KEY */
 } BUTTON;
 
-#define MAXBUTTONS 32
-#define MAXAXES 32
-
 typedef struct _JoystickDevRec {
     int          fd;          /* Actual file descriptor */
     void         *devicedata; /* Extra platform device dependend data */
@@ -106,7 +99,6 @@ typedef struct _JoystickDevRec {
 
     OsTimerPtr   timer;       /* Timer for axis movement */
     Bool         timerrunning;
-    float        x,y,zx,zy;   /* Pending subpixel movements */
 
     Bool         mouse_enabled, keys_enabled;
     float        amplify;     /* Global amplifier of axis movement */
